"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.lootboxes_api import LootboxesApi  # noqa: E501


class TestLootboxesApi(unittest.TestCase):
    """LootboxesApi unit test stubs"""

    def setUp(self):
        self.api = LootboxesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_lootbox_manager(self):
        """Test case for create_lootbox_manager

        Create lootbox manager  # noqa: E501
        """
        pass

    def test_get_lootbox_manager_lootbox(self):
        """Test case for get_lootbox_manager_lootbox

        Get lootbox manager lootbox  # noqa: E501
        """
        pass

    def test_get_lootbox_manager_lootboxes(self):
        """Test case for get_lootbox_manager_lootboxes

        Get lootbox manager lootboxes  # noqa: E501
        """
        pass

    def test_get_lootbox_managers(self):
        """Test case for get_lootbox_managers

        Get lootbox managers  # noqa: E501
        """
        pass

    def test_open_lootbox_manager_lootbox(self):
        """Test case for open_lootbox_manager_lootbox

        Open lootbox manager lootbox  # noqa: E501
        """
        pass

    def test_remove_lootbox_manager_lootbox(self):
        """Test case for remove_lootbox_manager_lootbox

        Remove lootbox manager lootbox  # noqa: E501
        """
        pass

    def test_set_lootbox_manager_lootbox(self):
        """Test case for set_lootbox_manager_lootbox

        Set lootbox manager lootbox  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
