"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.items_api import ItemsApi  # noqa: E501


class TestItemsApi(unittest.TestCase):
    """ItemsApi unit test stubs"""

    def setUp(self):
        self.api = ItemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_batch_mint_collection_items(self):
        """Test case for batch_mint_collection_items

        Batch mint collection items  # noqa: E501
        """
        pass

    def test_batch_transfer_collection_items(self):
        """Test case for batch_transfer_collection_items

        Batch transfer collection items  # noqa: E501
        """
        pass

    def test_burn_collection_item(self):
        """Test case for burn_collection_item

        Burn collection item  # noqa: E501
        """
        pass

    def test_create_collection(self):
        """Test case for create_collection

        Create collection  # noqa: E501
        """
        pass

    def test_create_collection_item(self):
        """Test case for create_collection_item

        Create collection item  # noqa: E501
        """
        pass

    def test_get_collection_approval(self):
        """Test case for get_collection_approval

        Get collection approval  # noqa: E501
        """
        pass

    def test_get_collection_item(self):
        """Test case for get_collection_item

        Get collection item  # noqa: E501
        """
        pass

    def test_get_collection_item_balance(self):
        """Test case for get_collection_item_balance

        Get collection item balance  # noqa: E501
        """
        pass

    def test_get_collection_item_balances(self):
        """Test case for get_collection_item_balances

        Get collection item balances  # noqa: E501
        """
        pass

    def test_get_collection_item_supplies(self):
        """Test case for get_collection_item_supplies

        Get collection item supplies  # noqa: E501
        """
        pass

    def test_get_collection_item_supply(self):
        """Test case for get_collection_item_supply

        Get collection item supply  # noqa: E501
        """
        pass

    def test_get_collection_item_timelock(self):
        """Test case for get_collection_item_timelock

        Get collection item timelock  # noqa: E501
        """
        pass

    def test_get_collection_items(self):
        """Test case for get_collection_items

        Get collection items  # noqa: E501
        """
        pass

    def test_get_collection_role(self):
        """Test case for get_collection_role

        Get collection role  # noqa: E501
        """
        pass

    def test_get_collections(self):
        """Test case for get_collections

        Get collections  # noqa: E501
        """
        pass

    def test_grant_collection_role(self):
        """Test case for grant_collection_role

        Grant collection role  # noqa: E501
        """
        pass

    def test_mint_collection_item(self):
        """Test case for mint_collection_item

        Mint collection item  # noqa: E501
        """
        pass

    def test_revoke_collection_role(self):
        """Test case for revoke_collection_role

        Revoke collection role  # noqa: E501
        """
        pass

    def test_set_collection_approval(self):
        """Test case for set_collection_approval

        Set collection approval  # noqa: E501
        """
        pass

    def test_set_collection_item_timelock(self):
        """Test case for set_collection_item_timelock

        Set collection item timelock  # noqa: E501
        """
        pass

    def test_transfer_collection_item(self):
        """Test case for transfer_collection_item

        Transfer collection item  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
