"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.shops_api import ShopsApi  # noqa: E501


class TestShopsApi(unittest.TestCase):
    """ShopsApi unit test stubs"""

    def setUp(self):
        self.api = ShopsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_shop(self):
        """Test case for create_shop

        Create shop  # noqa: E501
        """
        pass

    def test_get_shop_offer(self):
        """Test case for get_shop_offer

        Get shop offer  # noqa: E501
        """
        pass

    def test_get_shop_offers(self):
        """Test case for get_shop_offers

        Get shop offers  # noqa: E501
        """
        pass

    def test_get_shops(self):
        """Test case for get_shops

        Get shops  # noqa: E501
        """
        pass

    def test_remove_shop_offer(self):
        """Test case for remove_shop_offer

        Remove shop offer  # noqa: E501
        """
        pass

    def test_set_shop_offer(self):
        """Test case for set_shop_offer

        Set shop offer  # noqa: E501
        """
        pass

    def test_use_shop_offer(self):
        """Test case for use_shop_offer

        Use shop offer  # noqa: E501
        """
        pass

    def test_withdraw_from_shop(self):
        """Test case for withdraw_from_shop

        Withdraw from shop  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
