"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import metafab_python
from metafab_python.model.collection_model import CollectionModel
from metafab_python.model.contract_model import ContractModel
from metafab_python.model.get_collections200_response_inner_all_of import GetCollections200ResponseInnerAllOf
globals()['CollectionModel'] = CollectionModel
globals()['ContractModel'] = ContractModel
globals()['GetCollections200ResponseInnerAllOf'] = GetCollections200ResponseInnerAllOf
from metafab_python.model.get_collections200_response_inner import GetCollections200ResponseInner


class TestGetCollections200ResponseInner(unittest.TestCase):
    """GetCollections200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetCollections200ResponseInner(self):
        """Test GetCollections200ResponseInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetCollections200ResponseInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
