"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.currencies_api import CurrenciesApi  # noqa: E501


class TestCurrenciesApi(unittest.TestCase):
    """CurrenciesApi unit test stubs"""

    def setUp(self):
        self.api = CurrenciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_batch_transfer_currency(self):
        """Test case for batch_transfer_currency

        Batch transfer currency  # noqa: E501
        """
        pass

    def test_burn_currency(self):
        """Test case for burn_currency

        Burn currency  # noqa: E501
        """
        pass

    def test_create_currency(self):
        """Test case for create_currency

        Create currency  # noqa: E501
        """
        pass

    def test_get_currencies(self):
        """Test case for get_currencies

        Get currencies  # noqa: E501
        """
        pass

    def test_get_currency_balance(self):
        """Test case for get_currency_balance

        Get currency balance  # noqa: E501
        """
        pass

    def test_get_currency_fees(self):
        """Test case for get_currency_fees

        Get currency fees  # noqa: E501
        """
        pass

    def test_get_currency_role(self):
        """Test case for get_currency_role

        Get currency role  # noqa: E501
        """
        pass

    def test_grant_currency_role(self):
        """Test case for grant_currency_role

        Grant currency role  # noqa: E501
        """
        pass

    def test_mint_currency(self):
        """Test case for mint_currency

        Mint currency  # noqa: E501
        """
        pass

    def test_revoke_currency_role(self):
        """Test case for revoke_currency_role

        Revoke currency role  # noqa: E501
        """
        pass

    def test_set_currency_fees(self):
        """Test case for set_currency_fees

        Set currency fees  # noqa: E501
        """
        pass

    def test_transfer_currency(self):
        """Test case for transfer_currency

        Transfer currency  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
