"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.players_api import PlayersApi  # noqa: E501


class TestPlayersApi(unittest.TestCase):
    """PlayersApi unit test stubs"""

    def setUp(self):
        self.api = PlayersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_auth_player(self):
        """Test case for auth_player

        Authenticate player  # noqa: E501
        """
        pass

    def test_create_player(self):
        """Test case for create_player

        Create player  # noqa: E501
        """
        pass

    def test_get_player(self):
        """Test case for get_player

        Get player  # noqa: E501
        """
        pass

    def test_get_player_data(self):
        """Test case for get_player_data

        Get player data  # noqa: E501
        """
        pass

    def test_get_players(self):
        """Test case for get_players

        Get players  # noqa: E501
        """
        pass

    def test_set_player_data(self):
        """Test case for set_player_data

        Set player data  # noqa: E501
        """
        pass

    def test_update_player(self):
        """Test case for update_player

        Update player  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
