"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.games_api import GamesApi  # noqa: E501


class TestGamesApi(unittest.TestCase):
    """GamesApi unit test stubs"""

    def setUp(self):
        self.api = GamesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_auth_game(self):
        """Test case for auth_game

        Authenticate game  # noqa: E501
        """
        pass

    def test_create_game(self):
        """Test case for create_game

        Create game  # noqa: E501
        """
        pass

    def test_get_game(self):
        """Test case for get_game

        Get game  # noqa: E501
        """
        pass

    def test_update_game(self):
        """Test case for update_game

        Update game  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
