"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import metafab_python
from metafab_python.model.create_collection_request import CreateCollectionRequest


class TestCreateCollectionRequest(unittest.TestCase):
    """CreateCollectionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCollectionRequest(self):
        """Test CreateCollectionRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCollectionRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
