"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.transactions_api import TransactionsApi  # noqa: E501


class TestTransactionsApi(unittest.TestCase):
    """TransactionsApi unit test stubs"""

    def setUp(self):
        self.api = TransactionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transaction(self):
        """Test case for get_transaction

        Get transaction  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
