"""
    MetaFab API

     Complete MetaFab API references and guides can be found at: https://trymetafab.com  # noqa: E501

    The version of the OpenAPI document: 1.3.0
    Contact: metafabproject@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import metafab_python
from metafab_python.api.contracts_api import ContractsApi  # noqa: E501


class TestContractsApi(unittest.TestCase):
    """ContractsApi unit test stubs"""

    def setUp(self):
        self.api = ContractsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_contract(self):
        """Test case for create_contract

        Create custom contract  # noqa: E501
        """
        pass

    def test_get_contracts(self):
        """Test case for get_contracts

        Get contracts  # noqa: E501
        """
        pass

    def test_read_contract(self):
        """Test case for read_contract

        Read contract data  # noqa: E501
        """
        pass

    def test_write_contract(self):
        """Test case for write_contract

        Write contract data  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
